@@ -7,6 +7,7 @@ import (
 	"html"
 	"log/slog"
 	"path"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -35,8 +36,8 @@ func (r *RSSAdapter) BuildFeed(baseURL string) *model.Feed {
 	}
 
 	// Ensure the Site URL is absolute.
-	if siteURL, err := urllib.AbsoluteURL(baseURL, feed.SiteURL); err == nil {
-		feed.SiteURL = siteURL
+	if absoluteSiteURL, err := urllib.AbsoluteURL(baseURL, feed.SiteURL); err == nil {
+		feed.SiteURL = absoluteSiteURL
 	}
 
 	// Try to find the feed URL from the Atom links.
@@ -78,7 +79,13 @@ func (r *RSSAdapter) BuildFeed(baseURL string) *model.Feed {
 		// Populate the entry URL.
 		entryURL := findEntryURL(&item)
 		if entryURL == "" {
-			entry.URL = feed.SiteURL
+			// Fallback to the first enclosure URL if it exists.
+			if len(entry.Enclosures) > 0 && entry.Enclosures[0].URL != "" {
+				entry.URL = entry.Enclosures[0].URL
+			} else {
+				// Fallback to the feed URL if no entry URL is found.
+				entry.URL = feed.SiteURL
+			}
 		} else {
 			if absoluteEntryURL, err := urllib.AbsoluteURL(feed.SiteURL, entryURL); err == nil {
 				entry.URL = absoluteEntryURL
@@ -104,11 +111,11 @@ func (r *RSSAdapter) BuildFeed(baseURL string) *model.Feed {
 		// Generate the entry hash.
 		switch {
 		case item.GUID.Data != "":
-			entry.Hash = crypto.Hash(item.GUID.Data)
+			entry.Hash = crypto.SHA256(item.GUID.Data)
 		case entryURL != "":
-			entry.Hash = crypto.Hash(entryURL)
+			entry.Hash = crypto.SHA256(entryURL)
 		default:
-			entry.Hash = crypto.Hash(entry.Title + entry.Content)
+			entry.Hash = crypto.SHA256(entry.Title + entry.Content)
 		}
 
 		// Find CommentsURL if defined.
@@ -124,31 +131,13 @@ func (r *RSSAdapter) BuildFeed(baseURL string) *model.Feed {
 		}
 
 		// Populate entry categories.
-		for _, tag := range item.Categories {
-			if tag != "" {
-				entry.Tags = append(entry.Tags, tag)
-			}
-		}
-		for _, tag := range item.MediaCategories.Labels() {
-			if tag != "" {
-				entry.Tags = append(entry.Tags, tag)
-			}
-		}
+		entry.Tags = findEntryTags(&item)
 		if len(entry.Tags) == 0 {
-			for _, tag := range r.rss.Channel.Categories {
-				if tag != "" {
-					entry.Tags = append(entry.Tags, tag)
-				}
-			}
-			for _, tag := range r.rss.Channel.GetItunesCategories() {
-				if tag != "" {
-					entry.Tags = append(entry.Tags, tag)
-				}
-			}
-			if r.rss.Channel.GooglePlayCategory.Text != "" {
-				entry.Tags = append(entry.Tags, r.rss.Channel.GooglePlayCategory.Text)
-			}
+			entry.Tags = findFeedTags(&r.rss.Channel)
 		}
+		// Sort and deduplicate tags.
+		slices.Sort(entry.Tags)
+		entry.Tags = slices.Compact(entry.Tags)
 
 		feed.Entries = append(feed.Entries, entry)
 	}
@@ -169,8 +158,35 @@ func findFeedAuthor(rssChannel *RSSChannel) string {
 		author = rssChannel.ManagingEditor
 	case rssChannel.Webmaster != "":
 		author = rssChannel.Webmaster
+	default:
+		return ""
 	}
-	return sanitizer.StripTags(strings.TrimSpace(author))
+
+	return strings.TrimSpace(sanitizer.StripTags(author))
+}
+
+func findFeedTags(rssChannel *RSSChannel) []string {
+	tags := make([]string, 0)
+
+	for _, tag := range rssChannel.Categories {
+		tag = strings.TrimSpace(tag)
+		if tag != "" {
+			tags = append(tags, tag)
+		}
+	}
+
+	for _, tag := range rssChannel.GetItunesCategories() {
+		tag = strings.TrimSpace(tag)
+		if tag != "" {
+			tags = append(tags, tag)
+		}
+	}
+
+	if tag := strings.TrimSpace(rssChannel.GooglePlayCategory.Text); tag != "" {
+		tags = append(tags, tag)
+	}
+
+	return tags
 }
 
 func findEntryTitle(rssItem *RSSItem) string {
@@ -258,13 +274,35 @@ func findEntryAuthor(rssItem *RSSItem) string {
 		author = rssItem.PersonName()
 	case strings.Contains(rssItem.Author.Inner, "<![CDATA["):
 		author = rssItem.Author.Data
-	default:
+	case rssItem.Author.Inner != "":
 		author = rssItem.Author.Inner
+	default:
+		return ""
 	}
 
 	return strings.TrimSpace(sanitizer.StripTags(author))
 }
 
+func findEntryTags(rssItem *RSSItem) []string {
+	tags := make([]string, 0)
+
+	for _, tag := range rssItem.Categories {
+		tag = strings.TrimSpace(tag)
+		if tag != "" {
+			tags = append(tags, tag)
+		}
+	}
+
+	for _, tag := range rssItem.MediaCategories.Labels() {
+		tag = strings.TrimSpace(tag)
+		if tag != "" {
+			tags = append(tags, tag)
+		}
+	}
+
+	return tags
+}
+
 func findEntryEnclosures(rssItem *RSSItem, siteURL string) model.EnclosureList {
 	enclosures := make(model.EnclosureList, 0)
 	duplicates := make(map[string]bool)
