@@ -142,9 +142,6 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			espial_tags,
 			readwise_enabled,
 			readwise_api_key,
-			pocket_enabled,
-			pocket_access_token,
-			pocket_consumer_key,
 			telegram_bot_enabled,
 			telegram_bot_token,
 			telegram_bot_chat_id,
@@ -220,7 +217,10 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			pushover_token,
 			pushover_device,
 			pushover_prefix,
-			rssbridge_token
+			rssbridge_token,
+			karakeep_enabled,
+			karakeep_api_key,
+			karakeep_url
 		FROM
 			integrations
 		WHERE
@@ -261,9 +261,6 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.EspialTags,
 		&integration.ReadwiseEnabled,
 		&integration.ReadwiseAPIKey,
-		&integration.PocketEnabled,
-		&integration.PocketAccessToken,
-		&integration.PocketConsumerKey,
 		&integration.TelegramBotEnabled,
 		&integration.TelegramBotToken,
 		&integration.TelegramBotChatID,
@@ -340,6 +337,9 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.PushoverDevice,
 		&integration.PushoverPrefix,
 		&integration.RSSBridgeToken,
+		&integration.KarakeepEnabled,
+		&integration.KarakeepAPIKey,
+		&integration.KarakeepURL,
 	)
 	switch {
 	case err == sql.ErrNoRows:
@@ -377,97 +377,97 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 			nunux_keeper_enabled=$18,
 			nunux_keeper_url=$19,
 			nunux_keeper_api_key=$20,
-			pocket_enabled=$21,
-			pocket_access_token=$22,
-			pocket_consumer_key=$23,
-			googlereader_enabled=$24,
-			googlereader_username=$25,
-			googlereader_password=$26,
-			telegram_bot_enabled=$27,
-			telegram_bot_token=$28,
-			telegram_bot_chat_id=$29,
-			telegram_bot_topic_id=$30,
-			telegram_bot_disable_web_page_preview=$31,
-			telegram_bot_disable_notification=$32,
-			telegram_bot_disable_buttons=$33,
-			espial_enabled=$34,
-			espial_url=$35,
-			espial_api_key=$36,
-			espial_tags=$37,
-			linkace_enabled=$38,
-			linkace_url=$39,
-			linkace_api_key=$40,
-			linkace_tags=$41,
-			linkace_is_private=$42,
-			linkace_check_disabled=$43,
-			linkding_enabled=$44,
-			linkding_url=$45,
-			linkding_api_key=$46,
-			linkding_tags=$47,
-			linkding_mark_as_unread=$48,
-			matrix_bot_enabled=$49,
-			matrix_bot_user=$50,
-			matrix_bot_password=$51,
-			matrix_bot_url=$52,
-			matrix_bot_chat_id=$53,
-			notion_enabled=$54,
-			notion_token=$55,
-			notion_page_id=$56,
-			readwise_enabled=$57,
-			readwise_api_key=$58,
-			apprise_enabled=$59,
-			apprise_url=$60,
-			apprise_services_url=$61,
-			readeck_enabled=$62,
-			readeck_url=$63,
-			readeck_api_key=$64,
-			readeck_labels=$65,
-			readeck_only_url=$66,
-			shiori_enabled=$67,
-			shiori_url=$68,
-			shiori_username=$69,
-			shiori_password=$70,
-			shaarli_enabled=$71,
-			shaarli_url=$72,
-			shaarli_api_secret=$73,
-			webhook_enabled=$74,
-			webhook_url=$75,
-			webhook_secret=$76,
-			rssbridge_enabled=$77,
-			rssbridge_url=$78,
-			omnivore_enabled=$79,
-			omnivore_api_key=$80,
-			omnivore_url=$81,
-			linkwarden_enabled=$82,
-			linkwarden_url=$83,
-			linkwarden_api_key=$84,
-			raindrop_enabled=$85,
-			raindrop_token=$86,
-			raindrop_collection_id=$87,
-			raindrop_tags=$88,
-			betula_enabled=$89,
-			betula_url=$90,
-			betula_token=$91,
-			ntfy_enabled=$92,
-			ntfy_topic=$93,
-			ntfy_url=$94,
-			ntfy_api_token=$95,
-			ntfy_username=$96,
-			ntfy_password=$97,
-			ntfy_icon_url=$98,
-			ntfy_internal_links=$99,
-			cubox_enabled=$100,
-			cubox_api_link=$101,
-			discord_enabled=$102,
-			discord_webhook_link=$103,
-			slack_enabled=$104,
-			slack_webhook_link=$105,
-			pushover_enabled=$106,
-			pushover_user=$107,
-			pushover_token=$108,
-			pushover_device=$109,
-			pushover_prefix=$110,
-			rssbridge_token=$111
+			googlereader_enabled=$21,
+			googlereader_username=$22,
+			googlereader_password=$23,
+			telegram_bot_enabled=$24,
+			telegram_bot_token=$25,
+			telegram_bot_chat_id=$26,
+			telegram_bot_topic_id=$27,
+			telegram_bot_disable_web_page_preview=$28,
+			telegram_bot_disable_notification=$29,
+			telegram_bot_disable_buttons=$30,
+			espial_enabled=$31,
+			espial_url=$32,
+			espial_api_key=$33,
+			espial_tags=$34,
+			linkace_enabled=$35,
+			linkace_url=$36,
+			linkace_api_key=$37,
+			linkace_tags=$38,
+			linkace_is_private=$39,
+			linkace_check_disabled=$40,
+			linkding_enabled=$41,
+			linkding_url=$42,
+			linkding_api_key=$43,
+			linkding_tags=$44,
+			linkding_mark_as_unread=$45,
+			matrix_bot_enabled=$46,
+			matrix_bot_user=$47,
+			matrix_bot_password=$48,
+			matrix_bot_url=$49,
+			matrix_bot_chat_id=$50,
+			notion_enabled=$51,
+			notion_token=$52,
+			notion_page_id=$53,
+			readwise_enabled=$54,
+			readwise_api_key=$55,
+			apprise_enabled=$56,
+			apprise_url=$57,
+			apprise_services_url=$58,
+			readeck_enabled=$59,
+			readeck_url=$60,
+			readeck_api_key=$61,
+			readeck_labels=$62,
+			readeck_only_url=$63,
+			shiori_enabled=$64,
+			shiori_url=$65,
+			shiori_username=$66,
+			shiori_password=$67,
+			shaarli_enabled=$68,
+			shaarli_url=$69,
+			shaarli_api_secret=$70,
+			webhook_enabled=$71,
+			webhook_url=$72,
+			webhook_secret=$73,
+			rssbridge_enabled=$74,
+			rssbridge_url=$75,
+			omnivore_enabled=$76,
+			omnivore_api_key=$77,
+			omnivore_url=$78,
+			linkwarden_enabled=$79,
+			linkwarden_url=$80,
+			linkwarden_api_key=$81,
+			raindrop_enabled=$82,
+			raindrop_token=$83,
+			raindrop_collection_id=$84,
+			raindrop_tags=$85,
+			betula_enabled=$86,
+			betula_url=$87,
+			betula_token=$88,
+			ntfy_enabled=$89,
+			ntfy_topic=$90,
+			ntfy_url=$91,
+			ntfy_api_token=$92,
+			ntfy_username=$93,
+			ntfy_password=$94,
+			ntfy_icon_url=$95,
+			ntfy_internal_links=$96,
+			cubox_enabled=$97,
+			cubox_api_link=$98,
+			discord_enabled=$99,
+			discord_webhook_link=$100,
+			slack_enabled=$101,
+			slack_webhook_link=$102,
+			pushover_enabled=$103,
+			pushover_user=$104,
+			pushover_token=$105,
+			pushover_device=$106,
+			pushover_prefix=$107,
+			rssbridge_token=$108,
+			karakeep_enabled=$109,
+			karakeep_api_key=$110,
+			karakeep_url=$111
 		WHERE
 			user_id=$112
 	`
@@ -493,9 +493,6 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 		integration.NunuxKeeperEnabled,
 		integration.NunuxKeeperURL,
 		integration.NunuxKeeperAPIKey,
-		integration.PocketEnabled,
-		integration.PocketAccessToken,
-		integration.PocketConsumerKey,
 		integration.GoogleReaderEnabled,
 		integration.GoogleReaderUsername,
 		integration.GoogleReaderPassword,
@@ -584,6 +581,9 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 		integration.PushoverDevice,
 		integration.PushoverPrefix,
 		integration.RSSBridgeToken,
+		integration.KarakeepEnabled,
+		integration.KarakeepAPIKey,
+		integration.KarakeepURL,
 		integration.UserID,
 	)
 
@@ -612,7 +612,6 @@ func (s *Storage) HasSaveEntry(userID int64) (result bool) {
 				nunux_keeper_enabled='t' OR
 				espial_enabled='t' OR
 				readwise_enabled='t' OR
-				pocket_enabled='t' OR
 				linkace_enabled='t' OR
 				linkding_enabled='t' OR
 				linkwarden_enabled='t' OR
@@ -622,6 +621,7 @@ func (s *Storage) HasSaveEntry(userID int64) (result bool) {
 				shaarli_enabled='t' OR
 				webhook_enabled='t' OR
 				omnivore_enabled='t' OR
+				karakeep_enabled='t' OR
 				raindrop_enabled='t' OR
 				betula_enabled='t' OR
 				cubox_enabled='t' OR
